@@ -20,17 +20,14 @@
 #define IAPWS_H
 
 #include <Rmath.h>
-#define POW2(x) ((x) * (x))
-#define POWINT(x, y) R_pow_di((x), (y))
+#define POW2(x)		((x) * (x))
+#define POW(x, y)	R_pow((x), (y))
+#define POWINT(x, y)	R_pow_di((x), (y))
 
 #define IAPWS_TC	647.096		/* K	   */
 #define IAPWS_RHOC	322.0		/* kg/m3   */
 #define IAPWS_PC	22.064		/* MPa	   */
 
-extern int iapws_nroot_maxiter;
-extern double iapws_nroot_tolf;
-extern double iapws_nroot_tolx;
-
 typedef enum {
 	IAPWS_UNDEF = -1,
 	IAPWS_SOLID,
@@ -67,6 +64,5 @@ double iapws_w(const iapws_phi *phi);
 double iapws_alpha(const iapws_phi *phi);
 double iapws_beta(const iapws_phi *phi);
 double iapws_chit(const iapws_phi *phi);
-double iapws_sigma(const iapws_phi *phi);
 
 #endif
